should_enable_gc

Function should_enable_gc 

pub fn should_enable_gc(
    global_gc_enabled: bool,
    _object_store_scheme: &'static str,
) -> bool
Debug builds and unit tests use Fs to exercise object-store GC, including unit tests compiled with the release profile.